use std::collections::{HashMap, HashSet};
use std::env::args_os;

#[derive(Debug, Clone)]
pub struct Parser {
    flags: Vec<Flag>,
    args: Vec<Arg>,
    pos_args: Vec<PosArg>,

    // Used to ensure we don't get duplicate arguments.
    long_set: HashSet<String>,
    short_set: HashSet<String>,
}

#[derive(Debug, Clone)]
pub struct Arguments {
    // TODO: allow OsString argument values.
    /// Positional arguments, in the order passed.
    pub positional: Vec<String>,

    /// The flags that were passed.
    pub flags: HashSet<String>,

    /// Non-positional arguments that were passed.
    pub args: HashMap<String, String>,
}

//-------------------------------------------------------------

/// Flag spec.
#[derive(Debug, Clone)]
struct Flag {
    long: Option<String>,
    short: Option<String>,

    // For documentation.
    doc_string: String,
}

/// Argument spec.
#[derive(Debug, Clone)]
struct Arg {
    long: Option<String>,
    short: Option<String>,
    is_required: bool,

    // For documentation.
    value_name: String,
    doc_string: String,
}

/// Positional argument spec.
#[derive(Debug, Clone)]
struct PosArg {
    is_required: bool,

    // For documentation.
    value_name: String,
    doc_string: String,
}
